<?php

namespace Drupal\commerce_affiliatly;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

class CommerceAffiliatly {

  /**
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private $configFactory;

  /**
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  public function getAccountId() {
    return $this->getConfig()->get('id_affiliatly');
  }

  public function getSecurityHash() {
    return $this->getConfig()->get('security_hash');
  }

  public function getConfig() {
    return $this->configFactory->get('commerce_affiliatly.settings');
  }

  public function sendTracking(OrderInterface $order) {
    $accountId = $this->getAccountId();
    // Ensure that id exists.
    if (!$accountId) {
      return;
    }
    affiliatly_mark_purchase(
      $accountId,
      $order->id(),
      $order->getTotalPrice()->getNumber(),
      $this->getSecurityHash(),
      '',
      $this->getSkusFromOrder($order),
      $order->getEmail()
    );
  }

  /**
   * @param \Drupal\commerce_order\Entity\OrderInterface $order
   *
   * @return array
   */
  private function getSkusFromOrder(OrderInterface $order): array {
    /** @var \Drupal\commerce_order\Entity\OrderItemInterface[] $orderItems */
    $orderItems = $order->getItems();
    $skus = [];
    foreach ($orderItems as $orderItem) {
      /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $purchasedEntity */
      $purchasedEntity = $orderItem->getPurchasedEntity();
      $skus[] = [
        'id' => $purchasedEntity->getProductId(),
        'quantity' => $orderItem->getQuantity(),
        'price' => $orderItem->getTotalPrice()->getNumber(),
      ];
    }
    return $skus;
  }

}
